@@ -113,4 +113,9 @@ def delete_resources(tag_key: str, tag_value: str, region: str = "us-east-1", dr
     # of all performed actions, whether they were successful, and error messages for any actions
     # that were unsuccessful.
     for arn, obj in mapped_arns:
-        yield obj.destroy(arn, region, dry)
+
+        report = obj.destroy(arn, region, dry)
+        # Some reports are empty (e.g. KMS keys that have already been scheduled for deletion are
+        # picked up by the ResourceGroupsTaggingApi)
+        if len(report) > 0:
+            yield report
